@@ -6,7 +6,10 @@ from .repo import RepoImporter
 from .repo import ImportPathError
 
 from .commands import Command
+from .commands import git_command
 from .commands import default_commands
 
 from .hosts import Host
+from .hosts import github_host
+from .hosts import bitbucket_host
 from .hosts import default_hosts
